hgext/largefiles/overrides.py
changeset 23543 4dd8a6a1240d
parent 23541 495bc1b65d25
child 23575 a2f139d25845
--- a/hgext/largefiles/overrides.py	Sat Dec 13 09:45:00 2014 +0100
+++ b/hgext/largefiles/overrides.py	Thu Apr 17 22:47:38 2014 +0200
@@ -54,7 +54,7 @@
     was called.  no-op if scmutil.match is its original function.
 
     Note that n calls to installmatchfn will require n calls to
-    restore matchfn to reverse'''
+    restore the original matchfn.'''
     scmutil.match = getattr(scmutil.match, 'oldmatch')
 
 def installmatchandpatsfn(f):
@@ -69,7 +69,7 @@
     is its original function.
 
     Note that n calls to installmatchandpatsfn will require n calls
     to restore matchfn to reverse'''
     scmutil.matchandpats = getattr(scmutil.matchandpats, 'oldmatchandpats',
             scmutil.matchandpats)
 
@@ -376,7 +376,7 @@
         wlock.release()
 
 # Before starting the manifest merge, merge.updates will call
-# checkunknown to check if there are any files in the merged-in
+# _checkunknownfile to check if there are any files in the merged-in
 # changeset that collide with unknown files in the working copy.
 #
 # The largefiles are seen as unknown, so this prevents us from merging
@@ -69,7 +69,7 @@
 
     Note that n calls to installmatchandpatsfn will require n calls
-    to restore matchfn to reverse'''
+    to restore the original matchfn.'''
     scmutil.matchandpats = getattr(scmutil.matchandpats, 'oldmatchandpats',
             scmutil.matchandpats)